from gpjax.flax_base.types import BijectorLookupType, DomainType
import tensorflow_probability.substrates.jax.bijectors as tfb
import typing as tp

Bijectors: BijectorLookupType = {
    "real": tfb.Identity(),
    "positive": tfb.Softplus(),
}



import jax.numpy as jnp
import typing as tp
from flax.experimental import nnx
from gpjax.flax_base.types import DomainType, A


class AbstractParameter(nnx.Variable[A]):
    domain: DomainType = "real"
    static: bool = False

    def __init__(self, value: A, *args, **kwargs):
        super().__init__(jnp.asarray(value), *args, **kwargs)


class PositiveParameter(AbstractParameter[A]):
    domain: DomainType = "positive"



import typing as tp
import tensorflow_probability.substrates.jax.bijectors as tfb

DomainType = tp.Literal["real", "positive"]
A = tp.TypeVar("A")


# class BijectorLookup(tp.TypedDict):
#     domain: DomainType
#     bijector: tfb.Bijector

class BijectorLookupType(tp.Dict[DomainType, tfb.Bijector]):
    pass

__all__ = ["DomainType", "A", "BijectorLookupType"]
